# Changelog

## 0.1.0-alpha.2 (2025-05-30)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/vern-so/sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([4405800](https://github.com/vern-so/sdk-python/commit/440580072288fb17cd812dbbd53dc9106e3ca334))


### Chores

* **ci:** fix installation instructions ([8d2777c](https://github.com/vern-so/sdk-python/commit/8d2777c08354eee178d3a296cec8001a2620e85e))
* **ci:** upload sdks to package manager ([895acd3](https://github.com/vern-so/sdk-python/commit/895acd3e84c06b4e78e77ae830c1fc13729d4c39))
* **docs:** grammar improvements ([c57f739](https://github.com/vern-so/sdk-python/commit/c57f7396ad4d09bfde613186673a9ceb6dfd0d38))
* **internal:** codegen related update ([43756f6](https://github.com/vern-so/sdk-python/commit/43756f65287e0dcd2b54c44ea8ea625d2d99ac7e))

## 0.1.0-alpha.1 (2025-05-10)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/vern-so/sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([e853a88](https://github.com/vern-so/sdk-python/commit/e853a88a119171ec4712a7c968e573c12bd0fff0))


### Chores

* configure new SDK language ([7ab27a6](https://github.com/vern-so/sdk-python/commit/7ab27a6b37eeec4cc46f720d376265266fd2c378))
* update SDK settings ([311bd67](https://github.com/vern-so/sdk-python/commit/311bd671409b6f51a20acd0d0917997aa51830fd))
* update SDK settings ([7e3ad06](https://github.com/vern-so/sdk-python/commit/7e3ad062dfb2429be0d312da663a04c48ad5df46))
